# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/processing/processing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/processing/processing.proto',
  package='yamcs.protobuf.processing',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\017ProcessingProtoP\001'),
  serialized_pb=_b('\n*yamcs/protobuf/processing/processing.proto\x12\x19yamcs.protobuf.processing\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"q\n\x18GetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tfromCache\x18\x04 \x01(\x08\x12\x0f\n\x07timeout\x18\x05 \x01(\x04\"s\n\x18SetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12$\n\x05value\x18\x04 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"\x94\x01\n\x1e\x42\x61tchGetParameterValuesRequest\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x11\n\tprocessor\x18\x05 \x01(\t\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tfromCache\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x04\"W\n\x1f\x42\x61tchGetParameterValuesResponse\x12\x34\n\x05value\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\"\x97\x02\n\x1e\x42\x61tchSetParameterValuesRequest\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x11\n\tprocessor\x18\x03 \x01(\t\x12\x63\n\x07request\x18\x01 \x03(\x0b\x32R.yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest\x1ak\n\x18SetParameterValueRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"\xd2\x02\n\x13IssueCommandRequest\x12\x10\n\x08instance\x18\x06 \x01(\t\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12M\n\nassignment\x18\x01 \x03(\x0b\x32\x39.yamcs.protobuf.processing.IssueCommandRequest.Assignment\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x01(\x05\x12\x0e\n\x06\x64ryRun\x18\x04 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12\x45\n\tattribute\x18\t \x03(\x0b\x32\x32.yamcs.protobuf.commanding.CommandHistoryAttribute\x1a)\n\nAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xae\x02\n\x14IssueCommandResponse\x12\n\n\x02id\x18\x05 \x01(\t\x12\x32\n\x0egenerationTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x08 \x01(\x05\x12\x13\n\x0b\x63ommandName\x18\t \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0b\n\x03hex\x18\x03 \x01(\t\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x0c\x12\x10\n\x08username\x18\x0b \x01(\t\x12\r\n\x05queue\x18\n \x01(\t\x12K\n\x11\x63ommandQueueEntry\x18\x01 \x01(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntryB\x02\x18\x01\"\xf6\x01\n\x1bUpdateCommandHistoryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x33\n\x05\x63mdId\x18\x03 \x01(\x0b\x32$.yamcs.protobuf.commanding.CommandId\x12U\n\x0chistoryEntry\x18\x04 \x03(\x0b\x32?.yamcs.protobuf.processing.UpdateCommandHistoryRequest.KeyValue\x1a&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2\xa4\t\n\rProcessingApi\x12\xb0\x01\n\x11GetParameterValue\x12\x33.yamcs.protobuf.processing.GetParameterValueRequest\x1a%.yamcs.protobuf.pvalue.ParameterValue\"?\x8a\x92\x03;\n9/api/processors/{instance}/{processor}/parameters/{name*}\x12\xee\x01\n\x11SetParameterValue\x12\x33.yamcs.protobuf.processing.SetParameterValueRequest\x1a\x16.google.protobuf.Empty\"\x8b\x01\x8a\x92\x03\x86\x01\x12\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05valueZB\x1a\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05value\x12\xd5\x01\n\x17\x42\x61tchGetParameterValues\x12\x39.yamcs.protobuf.processing.BatchGetParameterValuesRequest\x1a:.yamcs.protobuf.processing.BatchGetParameterValuesResponse\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchGet:\x01*\x12\xb1\x01\n\x17\x42\x61tchSetParameterValues\x12\x39.yamcs.protobuf.processing.BatchSetParameterValuesRequest\x1a\x16.google.protobuf.Empty\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchSet:\x01*\x12\xb1\x01\n\x0cIssueCommand\x12..yamcs.protobuf.processing.IssueCommandRequest\x1a/.yamcs.protobuf.processing.IssueCommandResponse\"@\x8a\x92\x03<\x1a\x37/api/processors/{instance}/{processor}/commands/{name*}:\x01*\x12\xae\x01\n\x14UpdateCommandHistory\x12\x36.yamcs.protobuf.processing.UpdateCommandHistoryRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a=/api/processors/{instance}/{processor}/commandhistory/{name*}:\x01*B\'\n\x12org.yamcs.protobufB\x0fProcessingProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_GETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='GetParameterValueRequest',
  full_name='yamcs.protobuf.processing.GetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.GetParameterValueRequest.fromCache', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.GetParameterValueRequest.timeout', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=385,
)


_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.SetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.SetParameterValueRequest.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=502,
)


_BATCHGETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchGetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.instance', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.processor', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.id', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.fromCache', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.timeout', index=4,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=653,
)


_BATCHGETPARAMETERVALUESRESPONSE = _descriptor.Descriptor(
  name='BatchGetParameterValuesResponse',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=742,
)


_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=1024,
)

_BATCHSETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchSetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.instance', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.processor', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.request', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=1024,
)


_ISSUECOMMANDREQUEST_ASSIGNMENT = _descriptor.Descriptor(
  name='Assignment',
  full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1365,
)

_ISSUECOMMANDREQUEST = _descriptor.Descriptor(
  name='IssueCommandRequest',
  full_name='yamcs.protobuf.processing.IssueCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.IssueCommandRequest.instance', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.IssueCommandRequest.processor', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.IssueCommandRequest.name', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignment', full_name='yamcs.protobuf.processing.IssueCommandRequest.assignment', index=3,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.processing.IssueCommandRequest.origin', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.processing.IssueCommandRequest.sequenceNumber', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='yamcs.protobuf.processing.IssueCommandRequest.dryRun', index=6,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.processing.IssueCommandRequest.comment', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='yamcs.protobuf.processing.IssueCommandRequest.attribute', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDREQUEST_ASSIGNMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1027,
  serialized_end=1365,
)


_ISSUECOMMANDRESPONSE = _descriptor.Descriptor(
  name='IssueCommandResponse',
  full_name='yamcs.protobuf.processing.IssueCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.IssueCommandResponse.id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.processing.IssueCommandResponse.generationTime', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.processing.IssueCommandResponse.origin', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.processing.IssueCommandResponse.sequenceNumber', index=3,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.processing.IssueCommandResponse.commandName', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.processing.IssueCommandResponse.source', index=5,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hex', full_name='yamcs.protobuf.processing.IssueCommandResponse.hex', index=6,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.processing.IssueCommandResponse.binary', index=7,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.processing.IssueCommandResponse.username', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.processing.IssueCommandResponse.queue', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandQueueEntry', full_name='yamcs.protobuf.processing.IssueCommandResponse.commandQueueEntry', index=10,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1368,
  serialized_end=1670,
)


_UPDATECOMMANDHISTORYREQUEST_KEYVALUE = _descriptor.Descriptor(
  name='KeyValue',
  full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.KeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.KeyValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.KeyValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1881,
  serialized_end=1919,
)

_UPDATECOMMANDHISTORYREQUEST = _descriptor.Descriptor(
  name='UpdateCommandHistoryRequest',
  full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmdId', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.cmdId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historyEntry', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.historyEntry', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECOMMANDHISTORYREQUEST_KEYVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1673,
  serialized_end=1919,
)

_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BATCHGETPARAMETERVALUESREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHGETPARAMETERVALUESRESPONSE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.containing_type = _BATCHSETPARAMETERVALUESREQUEST
_BATCHSETPARAMETERVALUESREQUEST.fields_by_name['request'].message_type = _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST
_ISSUECOMMANDREQUEST_ASSIGNMENT.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST.fields_by_name['assignment'].message_type = _ISSUECOMMANDREQUEST_ASSIGNMENT
_ISSUECOMMANDREQUEST.fields_by_name['attribute'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYATTRIBUTE
_ISSUECOMMANDRESPONSE.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ISSUECOMMANDRESPONSE.fields_by_name['commandQueueEntry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEENTRY
_UPDATECOMMANDHISTORYREQUEST_KEYVALUE.containing_type = _UPDATECOMMANDHISTORYREQUEST
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['cmdId'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDID
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['historyEntry'].message_type = _UPDATECOMMANDHISTORYREQUEST_KEYVALUE
DESCRIPTOR.message_types_by_name['GetParameterValueRequest'] = _GETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetParameterValueRequest'] = _SETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesRequest'] = _BATCHGETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesResponse'] = _BATCHGETPARAMETERVALUESRESPONSE
DESCRIPTOR.message_types_by_name['BatchSetParameterValuesRequest'] = _BATCHSETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandRequest'] = _ISSUECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandResponse'] = _ISSUECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCommandHistoryRequest'] = _UPDATECOMMANDHISTORYREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetParameterValueRequest = _reflection.GeneratedProtocolMessageType('GetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetParameterValueRequest)
  })
_sym_db.RegisterMessage(GetParameterValueRequest)

SetParameterValueRequest = _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SetParameterValueRequest)
  })
_sym_db.RegisterMessage(SetParameterValueRequest)

BatchGetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesRequest)

BatchGetParameterValuesResponse = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesResponse)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesResponse)

BatchSetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchSetParameterValuesRequest', (_message.Message,), {

  'SetParameterValueRequest' : _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
    'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest)
    })
  ,
  'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchSetParameterValuesRequest)
_sym_db.RegisterMessage(BatchSetParameterValuesRequest.SetParameterValueRequest)

IssueCommandRequest = _reflection.GeneratedProtocolMessageType('IssueCommandRequest', (_message.Message,), {

  'Assignment' : _reflection.GeneratedProtocolMessageType('Assignment', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_ASSIGNMENT,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandRequest.Assignment)
    })
  ,
  'DESCRIPTOR' : _ISSUECOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandRequest)
  })
_sym_db.RegisterMessage(IssueCommandRequest)
_sym_db.RegisterMessage(IssueCommandRequest.Assignment)

IssueCommandResponse = _reflection.GeneratedProtocolMessageType('IssueCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISSUECOMMANDRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandResponse)
  })
_sym_db.RegisterMessage(IssueCommandResponse)

UpdateCommandHistoryRequest = _reflection.GeneratedProtocolMessageType('UpdateCommandHistoryRequest', (_message.Message,), {

  'KeyValue' : _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECOMMANDHISTORYREQUEST_KEYVALUE,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.UpdateCommandHistoryRequest.KeyValue)
    })
  ,
  'DESCRIPTOR' : _UPDATECOMMANDHISTORYREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.UpdateCommandHistoryRequest)
  })
_sym_db.RegisterMessage(UpdateCommandHistoryRequest)
_sym_db.RegisterMessage(UpdateCommandHistoryRequest.KeyValue)


DESCRIPTOR._options = None
_ISSUECOMMANDRESPONSE.fields_by_name['commandQueueEntry']._options = None

_PROCESSINGAPI = _descriptor.ServiceDescriptor(
  name='ProcessingApi',
  full_name='yamcs.protobuf.processing.ProcessingApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1922,
  serialized_end=3110,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetParameterValue',
    index=0,
    containing_service=None,
    input_type=_GETPARAMETERVALUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE,
    serialized_options=_b('\212\222\003;\n9/api/processors/{instance}/{processor}/parameters/{name*}'),
  ),
  _descriptor.MethodDescriptor(
    name='SetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.SetParameterValue',
    index=1,
    containing_service=None,
    input_type=_SETPARAMETERVALUEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003\206\001\0229/api/processors/{instance}/{processor}/parameters/{name*}:\005valueZB\0329/api/processors/{instance}/{processor}/parameters/{name*}:\005value'),
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchGetParameterValues',
    index=2,
    containing_service=None,
    input_type=_BATCHGETPARAMETERVALUESREQUEST,
    output_type=_BATCHGETPARAMETERVALUESRESPONSE,
    serialized_options=_b('\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchGet:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='BatchSetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchSetParameterValues',
    index=3,
    containing_service=None,
    input_type=_BATCHSETPARAMETERVALUESREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchSet:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='IssueCommand',
    full_name='yamcs.protobuf.processing.ProcessingApi.IssueCommand',
    index=4,
    containing_service=None,
    input_type=_ISSUECOMMANDREQUEST,
    output_type=_ISSUECOMMANDRESPONSE,
    serialized_options=_b('\212\222\003<\0327/api/processors/{instance}/{processor}/commands/{name*}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCommandHistory',
    full_name='yamcs.protobuf.processing.ProcessingApi.UpdateCommandHistory',
    index=5,
    containing_service=None,
    input_type=_UPDATECOMMANDHISTORYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003B\032=/api/processors/{instance}/{processor}/commandhistory/{name*}:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSINGAPI)

DESCRIPTOR.services_by_name['ProcessingApi'] = _PROCESSINGAPI

# @@protoc_insertion_point(module_scope)



import abc
import threading

from yamcs.core.exceptions import TimeoutError, YamcsError


class Future(object):

    """Future for capturing asynchronous execution.

    This interface is based on :class:`concurrent.futures.Future` available in Python 3 (not
    in Python 2).
    """

    @abc.abstractmethod
    def cancel(self):
        """
        Attempt to cancel the call. If the call is currently being executed and
        cannot be cancelled then the method will return False, otherwise the call
        will be cancelled and the method will return True.
        """
        raise NotImplementedError()

    @abc.abstractmethod
    def cancelled(self):
        """Return True if the call was successfully cancelled."""
        raise NotImplementedError()

    @abc.abstractmethod
    def running(self):
        """Return True if the call is currently being executed and cannot be cancelled."""
        raise NotImplementedError()

    @abc.abstractmethod
    def done(self):
        """Return True if the call was successfully cancelled or finished running."""
        raise NotImplementedError()

    @abc.abstractmethod
    def result(self, timeout=None):
        """
        Return the value returned by the call. If the call hasn't yet completed then
        this method will wait up to timeout seconds. If the call hasn't completed in
        timeout seconds, then a :class:`.TimeoutError` will be raised.
        timeout can be an int or float. If timeout is not specified or None, there
        is no limit to the wait time.

        If the future is cancelled before completing then CancelledError will be
        raised.

        If the call raised, this method will raise the same exception.
        """
        raise NotImplementedError()

    @abc.abstractmethod
    def exception(self, timeout=None):
        """
        Return the exception raised by the call. If the call hasn't yet completed
        then this method will wait up to timeout seconds. If the call hasn't
        completed in timeout seconds, then a :class:`.TimeoutError` will
        be raised. timeout can be an int or float. If timeout is not specified or
        None, there is no limit to the wait time.

        If the future is cancelled before completing then CancelledError will be
        raised.

        If the call completed without raising, None is returned.
        """
        raise NotImplementedError()

    @abc.abstractmethod
    def add_done_callback(self, fn):
        """
        Attaches the callable fn to the future. fn will be called, with the future
        as its only argument, when the future is cancelled or finishes running.

        Added callables are called in the order that they were added and are always
        called in a thread belonging to the process that added them. If the
        callable raises an Exception subclass, it will be logged and ignored. If
        the callable raises a BaseException subclass, the behavior is undefined.

        If the future has already completed or been cancelled, fn will be called
        immediately.
        """
        raise NotImplementedError()

    @abc.abstractmethod
    def set_result(self, result):
        """Sets the result of the work associated with the Future to result."""
        raise NotImplementedError()

    @abc.abstractmethod
    def set_exception(self, exception):
        """Sets the result of the work associated with the Future to the exception."""
        raise NotImplementedError()


class WebSocketSubscriptionFuture(Future):
    """
    Future for capturing the asynchronous execution of a WebSocket subscription.
    """

    def __init__(self, manager):
        super(WebSocketSubscriptionFuture, self).__init__()
        self._manager = manager
        self._manager.add_response_callback(self._on_response_callback)
        self._manager.add_close_callback(self._on_close_callback)

        # Yamcs send either a 'reply' message or an 'exception' message on
        # every websocket subscription. If the ``_response_received`` event
        # is set it means either of these two has arrived.
        self._response_received = threading.Event()
        self._response_reply = None
        self._response_exception = None

        self._result = None
        self._exception = None
        self._callbacks = []

        self._completed = threading.Event()
        self._cancelled = False

    def _on_response_callback(self, manager, reply=None, exception=None):
        self._response_reply = reply
        self._response_exception = exception
        self._response_received.set()

        # Yamcs leaves the socket open because it was designed with
        # multiple parallel subscriptions in mind. We don't use this
        # notion, so close the connection.
        if exception:
            closer = threading.Thread(
                target=self._manager.close,
                kwargs={'reason': exception},
            )
            closer.daemon = True
            closer.start()

    def _on_close_callback(self, manager, result):
        if result is None:
            self.set_result(True)
        else:
            self.set_exception(result)

    def cancel(self):
        """
        Closes the websocket and shutdowns the background thread consuming
        messages.
        """
        self._cancelled = True
        return self._manager.close()

    def cancelled(self):
        return self._cancelled

    def running(self):
        if self.done():
            return False
        return True

    def done(self):
        # We're assuming that None cannot be a valid result
        return (self._exception is not None or
                self._result is not None)

    def reply(self, timeout=None):
        """
        Returns the initial reply. This is emitted before any subscription
        data is emitted. This function raises an exception if the subscription
        attempt failed.
        """
        self._wait_on_signal(self._response_received)
        if self._response_exception is not None:
            msg = self._response_exception.message
            raise YamcsError(msg)
        return self._response_reply

    # pylint: disable-msg=E0702
    def result(self, timeout=None):
        err = self.exception(timeout=timeout)
        if err is None:
            return self._result
        raise err

    def exception(self, timeout=None):
        self._wait_on_signal(self._completed, timeout)

        if self._result is not None:
            return None

        return self._exception

    def _wait_on_signal(self, event, timeout=None):
        # Wait until the future is done. We do not use wait() without timeout
        # because on Python 2.x this does not generate ``KeyboardInterrupt``.
        # https://bugs.python.org/issue8844
        if timeout is not None:
            if not event.wait(timeout=timeout):
                # Remark that a timeout does *not* mean that the underlying
                # work is canceled.
                raise TimeoutError('Timed out.')
        else:
            # The actual timeout value does not have any impact
            while not event.wait(timeout=10):
                pass  # tick

    def add_done_callback(self, fn):
        if self.done():
            fn(self)
        self._callbacks.append(fn)

    def set_result(self, result):
        assert not self.done()

        self._result = result
        self._completed.set()
        for callback in self._callbacks:
            callback(self)

    def set_exception(self, exception):
        assert not self.done()

        self._exception = exception
        self._completed.set()
        for callback in self._callbacks:
            callback(self)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/rocksdb_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/rocksdb_service.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\023RocksDbServiceProtoP\001'),
  serialized_pb=_b('\n,yamcs/protobuf/archive/rocksdb_service.proto\x12\x16yamcs.protobuf.archive\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\"d\n\x1eListRocksDbTablespacesResponse\x12\x42\n\x0btablespaces\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.archive.RocksDbTablespaceInfo\"v\n\x15RocksDbTablespaceInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taDir\x18\x02 \x01(\t\x12>\n\tdatabases\x18\x03 \x03(\x0b\x32+.yamcs.protobuf.archive.RocksDbDatabaseInfo\"^\n\x1cListRocksDbDatabasesResponse\x12>\n\tdatabases\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.archive.RocksDbDatabaseInfo\"J\n\x13RocksDbDatabaseInfo\x12\x12\n\ntablespace\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taDir\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x62Path\x18\x03 \x01(\t\"N\n\x15\x42\x61\x63kupDatabaseRequest\x12\x12\n\ntablespace\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x62path\x18\x02 \x01(\t\x12\x11\n\tbackupDir\x18\x03 \x01(\t\"<\n\x16\x43ompactDatabaseRequest\x12\x12\n\ntablespace\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x62path\x18\x02 \x01(\t\"=\n\x17\x44\x65scribeDatabaseRequest\x12\x12\n\ntablespace\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x62path\x18\x02 \x01(\t2\xc9\x06\n\nRocksDbApi\x12\x89\x01\n\x0fListTablespaces\x12\x16.google.protobuf.Empty\x1a\x36.yamcs.protobuf.archive.ListRocksDbTablespacesResponse\"&\x8a\x92\x03\"\n /api/archive/rocksdb/tablespaces\x12\x91\x01\n\x0e\x42\x61\x63kupDatabase\x12-.yamcs.protobuf.archive.BackupDatabaseRequest\x1a\x16.google.protobuf.Empty\"8\x8a\x92\x03\x34\x1a\x32/api/archive/rocksdb/{tablespace}/{dbpath*}:backup\x12\x83\x01\n\rListDatabases\x12\x16.google.protobuf.Empty\x1a\x34.yamcs.protobuf.archive.ListRocksDbDatabasesResponse\"$\x8a\x92\x03 \n\x1e/api/archive/rocksdb/databases\x12\x97\x01\n\x0f\x43ompactDatabase\x12..yamcs.protobuf.archive.CompactDatabaseRequest\x1a\x16.google.protobuf.Empty\"<\x8a\x92\x03\x38\x1a\x34/api/archive/rocksdb/{tablespace}/{dbpath**}:compactH\x01\x12\x63\n\x0f\x44\x65scribeRocksDb\x12\x16.google.protobuf.Empty\x1a\x13.yamcs.api.HttpBody\"#\x8a\x92\x03\x1f\n\x1d/api/archive/rocksdb:describe\x12\x95\x01\n\x10\x44\x65scribeDatabase\x12/.yamcs.protobuf.archive.DescribeDatabaseRequest\x1a\x13.yamcs.api.HttpBody\";\x8a\x92\x03\x37\n5/api/archive/rocksdb/{tablespace}/{dbpath**}:describeB+\n\x12org.yamcs.protobufB\x13RocksDbServiceProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,])




_LISTROCKSDBTABLESPACESRESPONSE = _descriptor.Descriptor(
  name='ListRocksDbTablespacesResponse',
  full_name='yamcs.protobuf.archive.ListRocksDbTablespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tablespaces', full_name='yamcs.protobuf.archive.ListRocksDbTablespacesResponse.tablespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=256,
)


_ROCKSDBTABLESPACEINFO = _descriptor.Descriptor(
  name='RocksDbTablespaceInfo',
  full_name='yamcs.protobuf.archive.RocksDbTablespaceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.RocksDbTablespaceInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataDir', full_name='yamcs.protobuf.archive.RocksDbTablespaceInfo.dataDir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='databases', full_name='yamcs.protobuf.archive.RocksDbTablespaceInfo.databases', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=376,
)


_LISTROCKSDBDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListRocksDbDatabasesResponse',
  full_name='yamcs.protobuf.archive.ListRocksDbDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='yamcs.protobuf.archive.ListRocksDbDatabasesResponse.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=472,
)


_ROCKSDBDATABASEINFO = _descriptor.Descriptor(
  name='RocksDbDatabaseInfo',
  full_name='yamcs.protobuf.archive.RocksDbDatabaseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.archive.RocksDbDatabaseInfo.tablespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataDir', full_name='yamcs.protobuf.archive.RocksDbDatabaseInfo.dataDir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbPath', full_name='yamcs.protobuf.archive.RocksDbDatabaseInfo.dbPath', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=548,
)


_BACKUPDATABASEREQUEST = _descriptor.Descriptor(
  name='BackupDatabaseRequest',
  full_name='yamcs.protobuf.archive.BackupDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.archive.BackupDatabaseRequest.tablespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbpath', full_name='yamcs.protobuf.archive.BackupDatabaseRequest.dbpath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backupDir', full_name='yamcs.protobuf.archive.BackupDatabaseRequest.backupDir', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=628,
)


_COMPACTDATABASEREQUEST = _descriptor.Descriptor(
  name='CompactDatabaseRequest',
  full_name='yamcs.protobuf.archive.CompactDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.archive.CompactDatabaseRequest.tablespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbpath', full_name='yamcs.protobuf.archive.CompactDatabaseRequest.dbpath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=630,
  serialized_end=690,
)


_DESCRIBEDATABASEREQUEST = _descriptor.Descriptor(
  name='DescribeDatabaseRequest',
  full_name='yamcs.protobuf.archive.DescribeDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.archive.DescribeDatabaseRequest.tablespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbpath', full_name='yamcs.protobuf.archive.DescribeDatabaseRequest.dbpath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=692,
  serialized_end=753,
)

_LISTROCKSDBTABLESPACESRESPONSE.fields_by_name['tablespaces'].message_type = _ROCKSDBTABLESPACEINFO
_ROCKSDBTABLESPACEINFO.fields_by_name['databases'].message_type = _ROCKSDBDATABASEINFO
_LISTROCKSDBDATABASESRESPONSE.fields_by_name['databases'].message_type = _ROCKSDBDATABASEINFO
DESCRIPTOR.message_types_by_name['ListRocksDbTablespacesResponse'] = _LISTROCKSDBTABLESPACESRESPONSE
DESCRIPTOR.message_types_by_name['RocksDbTablespaceInfo'] = _ROCKSDBTABLESPACEINFO
DESCRIPTOR.message_types_by_name['ListRocksDbDatabasesResponse'] = _LISTROCKSDBDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['RocksDbDatabaseInfo'] = _ROCKSDBDATABASEINFO
DESCRIPTOR.message_types_by_name['BackupDatabaseRequest'] = _BACKUPDATABASEREQUEST
DESCRIPTOR.message_types_by_name['CompactDatabaseRequest'] = _COMPACTDATABASEREQUEST
DESCRIPTOR.message_types_by_name['DescribeDatabaseRequest'] = _DESCRIBEDATABASEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListRocksDbTablespacesResponse = _reflection.GeneratedProtocolMessageType('ListRocksDbTablespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROCKSDBTABLESPACESRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.rocksdb_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListRocksDbTablespacesResponse)
  })
_sym_db.RegisterMessage(ListRocksDbTablespacesResponse)

RocksDbTablespaceInfo = _reflection.GeneratedProtocolMessageType('RocksDbTablespaceInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROCKSDBTABLESPACEINFO,
  '__module__' : 'yamcs.protobuf.archive.rocksdb_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.RocksDbTablespaceInfo)
  })
_sym_db.RegisterMessage(RocksDbTablespaceInfo)

ListRocksDbDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListRocksDbDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROCKSDBDATABASESRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.rocksdb_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListRocksDbDatabasesResponse)
  })
_sym_db.RegisterMessage(ListRocksDbDatabasesResponse)

RocksDbDatabaseInfo = _reflection.GeneratedProtocolMessageType('RocksDbDatabaseInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROCKSDBDATABASEINFO,
  '__module__' : 'yamcs.protobuf.archive.rocksdb_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.RocksDbDatabaseInfo)
  })
_sym_db.RegisterMessage(RocksDbDatabaseInfo)

BackupDatabaseRequest = _reflection.GeneratedProtocolMessageType('BackupDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.archive.rocksdb_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.BackupDatabaseRequest)
  })
_sym_db.RegisterMessage(BackupDatabaseRequest)

CompactDatabaseRequest = _reflection.GeneratedProtocolMessageType('CompactDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPACTDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.archive.rocksdb_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.CompactDatabaseRequest)
  })
_sym_db.RegisterMessage(CompactDatabaseRequest)

DescribeDatabaseRequest = _reflection.GeneratedProtocolMessageType('DescribeDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.archive.rocksdb_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.DescribeDatabaseRequest)
  })
_sym_db.RegisterMessage(DescribeDatabaseRequest)


DESCRIPTOR._options = None

_ROCKSDBAPI = _descriptor.ServiceDescriptor(
  name='RocksDbApi',
  full_name='yamcs.protobuf.archive.RocksDbApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=756,
  serialized_end=1597,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListTablespaces',
    full_name='yamcs.protobuf.archive.RocksDbApi.ListTablespaces',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTROCKSDBTABLESPACESRESPONSE,
    serialized_options=_b('\212\222\003\"\n /api/archive/rocksdb/tablespaces'),
  ),
  _descriptor.MethodDescriptor(
    name='BackupDatabase',
    full_name='yamcs.protobuf.archive.RocksDbApi.BackupDatabase',
    index=1,
    containing_service=None,
    input_type=_BACKUPDATABASEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\0034\0322/api/archive/rocksdb/{tablespace}/{dbpath*}:backup'),
  ),
  _descriptor.MethodDescriptor(
    name='ListDatabases',
    full_name='yamcs.protobuf.archive.RocksDbApi.ListDatabases',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTROCKSDBDATABASESRESPONSE,
    serialized_options=_b('\212\222\003 \n\036/api/archive/rocksdb/databases'),
  ),
  _descriptor.MethodDescriptor(
    name='CompactDatabase',
    full_name='yamcs.protobuf.archive.RocksDbApi.CompactDatabase',
    index=3,
    containing_service=None,
    input_type=_COMPACTDATABASEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\0038\0324/api/archive/rocksdb/{tablespace}/{dbpath**}:compactH\001'),
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRocksDb',
    full_name='yamcs.protobuf.archive.RocksDbApi.DescribeRocksDb',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=_b('\212\222\003\037\n\035/api/archive/rocksdb:describe'),
  ),
  _descriptor.MethodDescriptor(
    name='DescribeDatabase',
    full_name='yamcs.protobuf.archive.RocksDbApi.DescribeDatabase',
    index=5,
    containing_service=None,
    input_type=_DESCRIBEDATABASEREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=_b('\212\222\0037\n5/api/archive/rocksdb/{tablespace}/{dbpath**}:describe'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ROCKSDBAPI)

DESCRIPTOR.services_by_name['RocksDbApi'] = _ROCKSDBAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/web/rest.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/web/rest.proto',
  package='yamcs.protobuf.web',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\tRestProtoP\001'),
  serialized_pb=_b('\n\x1dyamcs/protobuf/web/rest.proto\x12\x12yamcs.protobuf.web\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\"C\n\x12ListRoutesResponse\x12-\n\x06routes\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.web.RouteInfo\"\xc7\x01\n\tRouteInfo\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nhttpMethod\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x11\n\tinputType\x18\x06 \x01(\t\x12\x12\n\noutputType\x18\x07 \x01(\t\x12\x12\n\ndeprecated\x18\x08 \x01(\x08\x12\x14\n\x0crequestCount\x18\t \x01(\x03\x12\x12\n\nerrorCount\x18\n \x01(\x03\"\x8a\x02\n\x16GetGeneralInfoResponse\x12\x14\n\x0cyamcsVersion\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x06 \x01(\t\x12\x10\n\x08serverId\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ultYamcsInstance\x18\x03 \x01(\t\x12\x46\n\x07plugins\x18\x05 \x03(\x0b\x32\x35.yamcs.protobuf.web.GetGeneralInfoResponse.PluginInfo\x1aP\n\nPluginInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0e\n\x06vendor\x18\x04 \x01(\t\"p\n\x14ListCommandsResponse\x12=\n\x05\x65ntry\x18\x01 \x03(\x0b\x32..yamcs.protobuf.commanding.CommandHistoryEntry\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"(\n\x17\x45\x64itCommandQueueRequest\x12\r\n\x05state\x18\x01 \x01(\t\"Q\n\x13ListClientsResponse\x12:\n\x06\x63lient\x18\x01 \x03(\x0b\x32*.yamcs.protobuf.yamcsManagement.ClientInfo\"8\n\x11\x45\x64itClientRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"Z\n\x16ListProcessorsResponse\x12@\n\tprocessor\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\"W\n\x19ListCommandQueuesResponse\x12:\n\x05queue\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\"V\n\x17ListCommandQueueEntries\x12;\n\x05\x65ntry\x18\x01 \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\"-\n\x1c\x45\x64itCommandQueueEntryRequest\x12\r\n\x05state\x18\x01 \x01(\t\"j\n\x16\x43reateProcessorRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x06 \x03(\x05\x12\x12\n\npersistent\x18\x0b \x01(\x08\x12\x0c\n\x04type\x18\x0c \x01(\t\x12\x0e\n\x06\x63onfig\x18\r \x01(\t\"B\n\x14\x45\x64itProcessorRequest\x12\r\n\x05state\x18\x01 \x01(\t\x12\x0c\n\x04seek\x18\x02 \x01(\t\x12\r\n\x05speed\x18\x03 \x01(\t\"(\n\x16StreamSubscribeRequest\x12\x0e\n\x06stream\x18\x01 \x01(\t\"\x9d\x01\n\x18SetSimulationTimeRequest\x12\x16\n\nyamcsTime0\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x14\n\x08time0UTC\x18\x02 \x01(\tB\x02\x18\x01\x12\x16\n\x0esimElapsedTime\x18\x03 \x01(\x03\x12\x10\n\x08simSpeed\x18\x04 \x01(\x01\x12)\n\x05time0\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"W\n\x14\x42\x61tchGetIndexRequest\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x03(\t\x12\x12\n\npacketname\x18\x04 \x03(\t\"8\n\x14RestExceptionMessage\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03msg\x18\x02 \x01(\t*\x05\x08\x64\x10\xc9\x01\x32\xcf\x01\n\nGeneralApi\x12`\n\x0eGetGeneralInfo\x12\x16.google.protobuf.Empty\x1a*.yamcs.protobuf.web.GetGeneralInfoResponse\"\n\x8a\x92\x03\x06\n\x04/api\x12_\n\nListRoutes\x12\x16.google.protobuf.Empty\x1a&.yamcs.protobuf.web.ListRoutesResponse\"\x11\x8a\x92\x03\r\n\x0b/api/routesB!\n\x12org.yamcs.protobufB\tRestProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,])




_LISTROUTESRESPONSE = _descriptor.Descriptor(
  name='ListRoutesResponse',
  full_name='yamcs.protobuf.web.ListRoutesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routes', full_name='yamcs.protobuf.web.ListRoutesResponse.routes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=309,
)


_ROUTEINFO = _descriptor.Descriptor(
  name='RouteInfo',
  full_name='yamcs.protobuf.web.RouteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.web.RouteInfo.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.web.RouteInfo.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.web.RouteInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='httpMethod', full_name='yamcs.protobuf.web.RouteInfo.httpMethod', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='yamcs.protobuf.web.RouteInfo.url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputType', full_name='yamcs.protobuf.web.RouteInfo.inputType', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputType', full_name='yamcs.protobuf.web.RouteInfo.outputType', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='yamcs.protobuf.web.RouteInfo.deprecated', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requestCount', full_name='yamcs.protobuf.web.RouteInfo.requestCount', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorCount', full_name='yamcs.protobuf.web.RouteInfo.errorCount', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=511,
)


_GETGENERALINFORESPONSE_PLUGININFO = _descriptor.Descriptor(
  name='PluginInfo',
  full_name='yamcs.protobuf.web.GetGeneralInfoResponse.PluginInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.PluginInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.PluginInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.PluginInfo.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.PluginInfo.vendor', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=780,
)

_GETGENERALINFORESPONSE = _descriptor.Descriptor(
  name='GetGeneralInfoResponse',
  full_name='yamcs.protobuf.web.GetGeneralInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yamcsVersion', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.yamcsVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.revision', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.serverId', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultYamcsInstance', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.defaultYamcsInstance', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugins', full_name='yamcs.protobuf.web.GetGeneralInfoResponse.plugins', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETGENERALINFORESPONSE_PLUGININFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=780,
)


_LISTCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListCommandsResponse',
  full_name='yamcs.protobuf.web.ListCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.web.ListCommandsResponse.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.web.ListCommandsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=894,
)


_EDITCOMMANDQUEUEREQUEST = _descriptor.Descriptor(
  name='EditCommandQueueRequest',
  full_name='yamcs.protobuf.web.EditCommandQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.web.EditCommandQueueRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=936,
)


_LISTCLIENTSRESPONSE = _descriptor.Descriptor(
  name='ListClientsResponse',
  full_name='yamcs.protobuf.web.ListClientsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='yamcs.protobuf.web.ListClientsResponse.client', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1019,
)


_EDITCLIENTREQUEST = _descriptor.Descriptor(
  name='EditClientRequest',
  full_name='yamcs.protobuf.web.EditClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.EditClientRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.web.EditClientRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1077,
)


_LISTPROCESSORSRESPONSE = _descriptor.Descriptor(
  name='ListProcessorsResponse',
  full_name='yamcs.protobuf.web.ListProcessorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.web.ListProcessorsResponse.processor', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1169,
)


_LISTCOMMANDQUEUESRESPONSE = _descriptor.Descriptor(
  name='ListCommandQueuesResponse',
  full_name='yamcs.protobuf.web.ListCommandQueuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.web.ListCommandQueuesResponse.queue', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1258,
)


_LISTCOMMANDQUEUEENTRIES = _descriptor.Descriptor(
  name='ListCommandQueueEntries',
  full_name='yamcs.protobuf.web.ListCommandQueueEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.web.ListCommandQueueEntries.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1346,
)


_EDITCOMMANDQUEUEENTRYREQUEST = _descriptor.Descriptor(
  name='EditCommandQueueEntryRequest',
  full_name='yamcs.protobuf.web.EditCommandQueueEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.web.EditCommandQueueEntryRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1393,
)


_CREATEPROCESSORREQUEST = _descriptor.Descriptor(
  name='CreateProcessorRequest',
  full_name='yamcs.protobuf.web.CreateProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.web.CreateProcessorRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.web.CreateProcessorRequest.clientId', index=1,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.web.CreateProcessorRequest.persistent', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.CreateProcessorRequest.type', index=3,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.web.CreateProcessorRequest.config', index=4,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1501,
)


_EDITPROCESSORREQUEST = _descriptor.Descriptor(
  name='EditProcessorRequest',
  full_name='yamcs.protobuf.web.EditProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.web.EditProcessorRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seek', full_name='yamcs.protobuf.web.EditProcessorRequest.seek', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.web.EditProcessorRequest.speed', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1569,
)


_STREAMSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='StreamSubscribeRequest',
  full_name='yamcs.protobuf.web.StreamSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.web.StreamSubscribeRequest.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1571,
  serialized_end=1611,
)


_SETSIMULATIONTIMEREQUEST = _descriptor.Descriptor(
  name='SetSimulationTimeRequest',
  full_name='yamcs.protobuf.web.SetSimulationTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yamcsTime0', full_name='yamcs.protobuf.web.SetSimulationTimeRequest.yamcsTime0', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time0UTC', full_name='yamcs.protobuf.web.SetSimulationTimeRequest.time0UTC', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simElapsedTime', full_name='yamcs.protobuf.web.SetSimulationTimeRequest.simElapsedTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simSpeed', full_name='yamcs.protobuf.web.SetSimulationTimeRequest.simSpeed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time0', full_name='yamcs.protobuf.web.SetSimulationTimeRequest.time0', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1614,
  serialized_end=1771,
)


_BATCHGETINDEXREQUEST = _descriptor.Descriptor(
  name='BatchGetIndexRequest',
  full_name='yamcs.protobuf.web.BatchGetIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.web.BatchGetIndexRequest.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.web.BatchGetIndexRequest.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yamcs.protobuf.web.BatchGetIndexRequest.filter', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packetname', full_name='yamcs.protobuf.web.BatchGetIndexRequest.packetname', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1773,
  serialized_end=1860,
)


_RESTEXCEPTIONMESSAGE = _descriptor.Descriptor(
  name='RestExceptionMessage',
  full_name='yamcs.protobuf.web.RestExceptionMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.RestExceptionMessage.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='yamcs.protobuf.web.RestExceptionMessage.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(100, 201), ],
  oneofs=[
  ],
  serialized_start=1862,
  serialized_end=1918,
)

_LISTROUTESRESPONSE.fields_by_name['routes'].message_type = _ROUTEINFO
_GETGENERALINFORESPONSE_PLUGININFO.containing_type = _GETGENERALINFORESPONSE
_GETGENERALINFORESPONSE.fields_by_name['plugins'].message_type = _GETGENERALINFORESPONSE_PLUGININFO
_LISTCOMMANDSRESPONSE.fields_by_name['entry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY
_LISTCLIENTSRESPONSE.fields_by_name['client'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._CLIENTINFO
_LISTPROCESSORSRESPONSE.fields_by_name['processor'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_LISTCOMMANDQUEUESRESPONSE.fields_by_name['queue'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO
_LISTCOMMANDQUEUEENTRIES.fields_by_name['entry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEENTRY
_SETSIMULATIONTIMEREQUEST.fields_by_name['time0'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListRoutesResponse'] = _LISTROUTESRESPONSE
DESCRIPTOR.message_types_by_name['RouteInfo'] = _ROUTEINFO
DESCRIPTOR.message_types_by_name['GetGeneralInfoResponse'] = _GETGENERALINFORESPONSE
DESCRIPTOR.message_types_by_name['ListCommandsResponse'] = _LISTCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['EditCommandQueueRequest'] = _EDITCOMMANDQUEUEREQUEST
DESCRIPTOR.message_types_by_name['ListClientsResponse'] = _LISTCLIENTSRESPONSE
DESCRIPTOR.message_types_by_name['EditClientRequest'] = _EDITCLIENTREQUEST
DESCRIPTOR.message_types_by_name['ListProcessorsResponse'] = _LISTPROCESSORSRESPONSE
DESCRIPTOR.message_types_by_name['ListCommandQueuesResponse'] = _LISTCOMMANDQUEUESRESPONSE
DESCRIPTOR.message_types_by_name['ListCommandQueueEntries'] = _LISTCOMMANDQUEUEENTRIES
DESCRIPTOR.message_types_by_name['EditCommandQueueEntryRequest'] = _EDITCOMMANDQUEUEENTRYREQUEST
DESCRIPTOR.message_types_by_name['CreateProcessorRequest'] = _CREATEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['EditProcessorRequest'] = _EDITPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['StreamSubscribeRequest'] = _STREAMSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['SetSimulationTimeRequest'] = _SETSIMULATIONTIMEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetIndexRequest'] = _BATCHGETINDEXREQUEST
DESCRIPTOR.message_types_by_name['RestExceptionMessage'] = _RESTEXCEPTIONMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListRoutesResponse = _reflection.GeneratedProtocolMessageType('ListRoutesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROUTESRESPONSE,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListRoutesResponse)
  })
_sym_db.RegisterMessage(ListRoutesResponse)

RouteInfo = _reflection.GeneratedProtocolMessageType('RouteInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEINFO,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.RouteInfo)
  })
_sym_db.RegisterMessage(RouteInfo)

GetGeneralInfoResponse = _reflection.GeneratedProtocolMessageType('GetGeneralInfoResponse', (_message.Message,), {

  'PluginInfo' : _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
    'DESCRIPTOR' : _GETGENERALINFORESPONSE_PLUGININFO,
    '__module__' : 'yamcs.protobuf.web.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.GetGeneralInfoResponse.PluginInfo)
    })
  ,
  'DESCRIPTOR' : _GETGENERALINFORESPONSE,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.GetGeneralInfoResponse)
  })
_sym_db.RegisterMessage(GetGeneralInfoResponse)
_sym_db.RegisterMessage(GetGeneralInfoResponse.PluginInfo)

ListCommandsResponse = _reflection.GeneratedProtocolMessageType('ListCommandsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSRESPONSE,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListCommandsResponse)
  })
_sym_db.RegisterMessage(ListCommandsResponse)

EditCommandQueueRequest = _reflection.GeneratedProtocolMessageType('EditCommandQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITCOMMANDQUEUEREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.EditCommandQueueRequest)
  })
_sym_db.RegisterMessage(EditCommandQueueRequest)

ListClientsResponse = _reflection.GeneratedProtocolMessageType('ListClientsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLIENTSRESPONSE,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListClientsResponse)
  })
_sym_db.RegisterMessage(ListClientsResponse)

EditClientRequest = _reflection.GeneratedProtocolMessageType('EditClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITCLIENTREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.EditClientRequest)
  })
_sym_db.RegisterMessage(EditClientRequest)

ListProcessorsResponse = _reflection.GeneratedProtocolMessageType('ListProcessorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORSRESPONSE,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListProcessorsResponse)
  })
_sym_db.RegisterMessage(ListProcessorsResponse)

ListCommandQueuesResponse = _reflection.GeneratedProtocolMessageType('ListCommandQueuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDQUEUESRESPONSE,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListCommandQueuesResponse)
  })
_sym_db.RegisterMessage(ListCommandQueuesResponse)

ListCommandQueueEntries = _reflection.GeneratedProtocolMessageType('ListCommandQueueEntries', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDQUEUEENTRIES,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListCommandQueueEntries)
  })
_sym_db.RegisterMessage(ListCommandQueueEntries)

EditCommandQueueEntryRequest = _reflection.GeneratedProtocolMessageType('EditCommandQueueEntryRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITCOMMANDQUEUEENTRYREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.EditCommandQueueEntryRequest)
  })
_sym_db.RegisterMessage(EditCommandQueueEntryRequest)

CreateProcessorRequest = _reflection.GeneratedProtocolMessageType('CreateProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.CreateProcessorRequest)
  })
_sym_db.RegisterMessage(CreateProcessorRequest)

EditProcessorRequest = _reflection.GeneratedProtocolMessageType('EditProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.EditProcessorRequest)
  })
_sym_db.RegisterMessage(EditProcessorRequest)

StreamSubscribeRequest = _reflection.GeneratedProtocolMessageType('StreamSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSUBSCRIBEREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.StreamSubscribeRequest)
  })
_sym_db.RegisterMessage(StreamSubscribeRequest)

SetSimulationTimeRequest = _reflection.GeneratedProtocolMessageType('SetSimulationTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSIMULATIONTIMEREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.SetSimulationTimeRequest)
  })
_sym_db.RegisterMessage(SetSimulationTimeRequest)

BatchGetIndexRequest = _reflection.GeneratedProtocolMessageType('BatchGetIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.BatchGetIndexRequest)
  })
_sym_db.RegisterMessage(BatchGetIndexRequest)

RestExceptionMessage = _reflection.GeneratedProtocolMessageType('RestExceptionMessage', (_message.Message,), {
  'DESCRIPTOR' : _RESTEXCEPTIONMESSAGE,
  '__module__' : 'yamcs.protobuf.web.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.RestExceptionMessage)
  })
_sym_db.RegisterMessage(RestExceptionMessage)


DESCRIPTOR._options = None
_SETSIMULATIONTIMEREQUEST.fields_by_name['yamcsTime0']._options = None
_SETSIMULATIONTIMEREQUEST.fields_by_name['time0UTC']._options = None

_GENERALAPI = _descriptor.ServiceDescriptor(
  name='GeneralApi',
  full_name='yamcs.protobuf.web.GeneralApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1921,
  serialized_end=2128,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetGeneralInfo',
    full_name='yamcs.protobuf.web.GeneralApi.GetGeneralInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETGENERALINFORESPONSE,
    serialized_options=_b('\212\222\003\006\n\004/api'),
  ),
  _descriptor.MethodDescriptor(
    name='ListRoutes',
    full_name='yamcs.protobuf.web.GeneralApi.ListRoutes',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTROUTESRESPONSE,
    serialized_options=_b('\212\222\003\r\n\013/api/routes'),
  ),
])
_sym_db.RegisterServiceDescriptor(_GENERALAPI)

DESCRIPTOR.services_by_name['GeneralApi'] = _GENERALAPI

# @@protoc_insertion_point(module_scope)



from yamcs.core.helpers import parse_isostring, parse_value


class Table(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Table name."""
        return self._proto.name

    def __str__(self):
        return self.name


class Stream(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Stream name."""
        return self._proto.name

    def __str__(self):
        return self.name


class StreamData(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def stream(self):
        """Stream name."""
        return self._proto.stream

    @property
    def columns(self):
        """Tuple columns."""
        return [ColumnData(c) for c in self._proto.column]

    def __str__(self):
        return '{} ({} columns)'.format(self.stream, len(self.columns))


class ColumnData(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Column name."""
        return self._proto.name

    @property
    def value(self):
        """Value for this column."""
        return parse_value(self._proto.value)

    def __str__(self):
        return '{}: {}'.format(self.name, self.value)


class IndexGroup(object):
    """
    Group of index records that represent the same
    type of underlying objects.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """
        Name associated with this group. The meaning is defined
        by the objects represented by this index. For example:

        * In an index of events, index records are grouped by ``source``.
        * In an index of packets, index records are grouped by ``packet name``.
        """
        if self._proto.HasField('id'):
            return self._proto.id.name
        return None

    @property
    def records(self):
        """
        Index records within this group

        :type: List[:class:`.IndexRecord`]
        """
        return [IndexRecord(rec) for rec in self._proto.entry]

    def __str__(self):
        return '{} ({} records)'.format(self.name, len(self.records))


class IndexRecord(object):
    """
    Represents a block of uninterrupted data (derived from the index definition
    for the type of underlying objects, in combination with the requested
    ``merge_time``.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def start(self):
        """
        Start time of the record

        :type: :class:`~datetime.datetime`
        """
        return parse_isostring(self._proto.start)

    @property
    def stop(self):
        """
        Stop time of the record

        :type: :class:`~datetime.datetime`
        """
        return parse_isostring(self._proto.stop)

    @property
    def count(self):
        """
        Number of underlying objects this index record represents
        """
        return self._proto.count

    def __str__(self):
        return '{} - {} (n={})'.format(self.start, self.stop, self.count)


class Packet(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """
        The name of the packet. When using XTCE extraction this is the
        fully-qualified name of the first container in the hierarchy that
        this packet maps to.
        """
        if self._proto.HasField('id'):
            return self._proto.id.name
        return None

    @property
    def generation_time(self):
        """
        The time when the packet was generated (packet time).

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('generationTimeUTC'):
            return parse_isostring(self._proto.generationTimeUTC)
        return None

    @property
    def reception_time(self):
        """
        The time when the packet was received by Yamcs.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('receptionTimeUTC'):
            return parse_isostring(self._proto.receptionTimeUTC)
        return None

    @property
    def sequence_number(self):
        """
        The sequence number of the packet. This is usually decoded from
        the packet.
        """
        if self._proto.HasField('sequenceNumber'):
            return self._proto.sequenceNumber
        return None

    @property
    def binary(self):
        """
        Raw binary of this packet
        """
        if self._proto.HasField('packet'):
            return self._proto.packet
        return None

    def __str__(self):
        return '{} #{} ({})'.format(self.generation_time, self.sequence_number, self.name)


class Sample(object):
    """
    Provides aggregation properties over a range of a parameter's
    values.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def time(self):
        """
        Sample time.

        :type: :class:`~datetime.datetime`
        """
        return parse_isostring(self._proto.time)

    @property
    def avg(self):
        """Average value."""
        if self._proto.HasField('avg'):
            return self._proto.avg
        return None

    @property
    def min(self):
        """Minimum value."""
        if self._proto.HasField('min'):
            return self._proto.min
        return None

    @property
    def max(self):
        """Maximum value."""
        if self._proto.HasField('max'):
            return self._proto.max
        return None

    @property
    def parameter_count(self):
        """The number of parameter values this sample represents."""
        return self._proto.n

    def __str__(self):
        return '{} {}'.format(self.time, self.avg)


class ParameterRange(object):
    """
    Indicates an interval during which a parameter's
    value was uninterrupted and unchanged.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def start(self):
        """
        Start time of this range (inclusive).

        :type: :class:`~datetime.datetime`
        """
        return parse_isostring(self._proto.timeStart)

    @property
    def stop(self):
        """
        Stop time of this range (exclusive).

        :type: :class:`~datetime.datetime`
        """
        return parse_isostring(self._proto.timeStop)

    @property
    def eng_value(self):
        """The engineering (calibrated) value."""
        return parse_value(self._proto.engValue)

    @property
    def parameter_count(self):
        """The number of received parameter values during this range."""
        return self._proto.count

    def __str__(self):
        return '{} - {}: {}'.format(self.start, self.stop, self.eng_value)



from datetime import datetime, timedelta

import pkg_resources
import requests
import six
import urllib3
from google.protobuf.message import DecodeError
from requests.auth import HTTPBasicAuth
from yamcs.core.auth import Credentials
from yamcs.core.exceptions import (ConnectionFailure, NotFound, Unauthorized,
                                   YamcsError)
from yamcs.protobuf.web import rest_pb2


def _convert_user_credentials(session, token_url, username=None, password=None, refresh_token=None):
    """
    Converts username/password credentials to token credentials by
    using Yamcs as the authentication server.
    """
    if username and password:
        data = {'grant_type': 'password', 'username': username, 'password': password}
    elif refresh_token:
        data = {'grant_type': 'refresh_token', 'refresh_token': refresh_token}
    else:
        raise NotImplementedError()

    response = session.post(token_url, data=data)
    if response.status_code == 401:
        raise Unauthorized('401 Client Error: Unauthorized')
    elif response.status_code == 200:
        d = response.json()
        expiry = datetime.utcnow() + timedelta(seconds=d['expires_in'])
        return Credentials(access_token=d['access_token'],
                           refresh_token=d['refresh_token'],
                           expiry=expiry)
    else:
        raise YamcsError('{} Server Error'.format(response.status_code))


def _convert_service_account_credentials(session, token_url, client_id,
                                         client_secret, become):
    """
    Converts service account credentials to impersonated token credentials.
    """
    data = {'grant_type': 'client_credentials', 'become': become}

    response = session.post(token_url, data=data,
                            auth=HTTPBasicAuth(client_id, client_secret))
    if response.status_code == 401:
        raise Unauthorized('401 Client Error: Unauthorized')
    elif response.status_code == 200:
        d = response.json()
        expiry = datetime.utcnow() + timedelta(seconds=d['expires_in'])
        return Credentials(access_token=d['access_token'],
                           client_id=client_id,
                           client_secret=client_secret,
                           become=become,
                           expiry=expiry)
    else:
        raise YamcsError('{} Server Error'.format(response.status_code))


class BaseClient(object):

    def __init__(self, address, tls=False, credentials=None, user_agent=None,
                 on_token_update=None, tls_verify=True):
        if ':' in address:
            self.address = address
        else:
            self.address = address + ':8090'

        if tls:
            self.auth_root = 'https://{}/auth'.format(self.address)
            self.api_root = 'https://{}/api'.format(self.address)
            self.ws_root = 'wss://{}/_websocket'.format(self.address)
        else:
            self.auth_root = 'http://{}/auth'.format(self.address)
            self.api_root = 'http://{}/api'.format(self.address)
            self.ws_root = 'ws://{}/_websocket'.format(self.address)

        self.session = requests.Session()
        if not tls_verify:
            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
            self.session.verify = False

        self.on_token_update = on_token_update
        self.credentials = credentials
        token_url = self.auth_root + '/token'
        if self.credentials and self.credentials.username:  # Convert u/p to bearer
            self.credentials = _convert_user_credentials(
                self.session,
                token_url,
                username=self.credentials.username,
                password=self.credentials.password)
            if self.on_token_update:
                self.on_token_update(self.credentials)
        if self.credentials and self.credentials.become:  # Impersonate from service account
            self.credentials = _convert_service_account_credentials(
                self.session,
                token_url,
                client_id=self.credentials.client_id,
                client_secret=self.credentials.client_secret,
                become=self.credentials.become,
            )

        if self.credentials and self.credentials.access_token:
            self._update_authorization_header()

        if not user_agent:
            dist = pkg_resources.get_distribution('yamcs-client')
            user_agent = 'yamcs-python-client v' + dist.version
        self.session.headers.update({'User-Agent': user_agent})

    def _update_authorization_header(self):
        self.session.headers.update({
            'Authorization': 'Bearer ' + self.credentials.access_token
        })

    def get_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('get', path, **kwargs)

    def put_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Content-Type'] = 'application/protobuf'
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('put', path, **kwargs)

    def patch_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Content-Type'] = 'application/protobuf'
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('patch', path, **kwargs)

    def post_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Content-Type'] = 'application/protobuf'
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('post', path, **kwargs)

    def delete_proto(self, path, **kwargs):
        headers = kwargs.pop('headers', {})
        headers['Accept'] = 'application/protobuf'
        kwargs.update({'headers': headers})
        return self.request('delete', path, **kwargs)

    def _refresh_access_token(self):
        if self.credentials.become:
            self.credentials = _convert_service_account_credentials(
                self.session,
                self.auth_root + '/token',
                client_id=self.credentials.client_id,
                client_secret=self.credentials.client_secret,
                become=self.credentials.become)
        else:
            self.credentials = _convert_user_credentials(
                self.session,
                self.auth_root + '/token',
                refresh_token=self.credentials.refresh_token)
        self._update_authorization_header()
        if self.on_token_update:
            self.on_token_update(self.credentials)

    def request(self, method, path, **kwargs):
        path = '{}{}'.format(self.api_root, path)

        if self.credentials and self.credentials.is_expired():
            self._refresh_access_token()

        try:
            response = self.session.request(method, path, **kwargs)
        except requests.exceptions.SSLError as sslError:
            msg = 'Connection to {} failed: {}'.format(self.address, sslError)
            six.raise_from(ConnectionFailure(msg), None)
        except requests.exceptions.ConnectionError:
            raise ConnectionFailure('Connection to {} refused'.format(self.address))

        if 200 <= response.status_code < 300:
            return response

        exception_message = rest_pb2.RestExceptionMessage()
        try:
            exception_message.ParseFromString(response.content)
        except DecodeError:
            pass

        if response.status_code == 401:
            raise Unauthorized('401 Client Error: Unauthorized')
        elif response.status_code == 404:
            raise NotFound('404 Client Error: {}'.format(
                exception_message.msg))
        elif 400 <= response.status_code < 500:
            raise YamcsError('{} Client Error: {}'.format(
                response.status_code, exception_message.msg))
        raise YamcsError('{} Server Error: {}'.format(
            response.status_code, exception_message.msg))
